kwimage.algo.\_nms\_backend package
===================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   kwimage.algo._nms_backend.py_nms
   kwimage.algo._nms_backend.torch_nms

Module contents
---------------

.. automodule:: kwimage.algo._nms_backend
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
